# Installation Guide

GNATSS is compatible with Python versions 3.10-3.11. If you have a conda
installation, we recommend creating a fresh environment to install GNATSS in.

```
conda create -n gnatss -c conda-forge --yes python=3.10 ipykernel
conda activate gnatss
```

Once you have the appropriate python environment enabled, GNATSS may be
installed via pip:

```
pip install gnatss
```

In order to update GNATSS to the most current version, use the command:

```
pip install --upgrade gnatss
```
